@@ -24,11 +24,14 @@ RFgui <- function(data, x, y,
   if (wait >= 0) {
     while (!exists(".RFgui.exit", envir=Env)) .C("sleepMicro", as.integer(wait))
     res <- get("RFgui.model", envir=Env)
-    if (RFoptions()$general$spConform) { 
+    if (is.null(res)) return(res) #; Print(res)
+    if (RFoptions()$general$spConform) {
       RFvariogram(model=res, x=0)
       res <- list2RMmodel(GetModel(RFvariogram))
+    } else {
+      class(res) <- "RM_model"
+      invisible(res)
     }
-    invisible(res)
   } else invisible(NULL)
 }
 
@@ -40,7 +43,6 @@ rfgui.intern <- function(data, x, y,
                          sim_only1dim=FALSE,                         
                          parent.ev=NULL,
                          printlevel=0,...) {
-  simuMethod <- "circulant"
   circ.trials <- 1
   circ.force <- TRUE
   circ.min <- -2
@@ -50,8 +52,8 @@ rfgui.intern <- function(data, x, y,
   if (missing(xcov)) xcov <- NULL
   if (missing(ycov)) ycov <- NULL
   
-  if (!do.call("require", list("tcltk", quietly=TRUE)) ||
-      !do.call("require", list("tkrplot", quietly=TRUE)))
+  if (!do.call(base::require, list("tcltk", quietly=TRUE)) ||
+      !do.call(base::require, list("tkrplot", quietly=TRUE)))
     stop("To use 'RFgui' the tcl/tk packages 'tcltk' and 'tkrplot' must be installed.")
   
   tclRequire("BWidget", warn=!FALSE)
@@ -62,9 +64,10 @@ rfgui.intern <- function(data, x, y,
   RFoptOld <- if (same.alg)
     internal.rfoptions(storing=FALSE, printlevel=printlevel - 10,
                        circulant.trials=circ.trials,
-                       gui.simu_method = simuMethod,
                        circulant.force=circ.force,
-                       circulant.mmin=circ.min, ...)
+                       circulant.mmin=circ.min, ...,
+                       graphics.height=-1
+                       )
   else  internal.rfoptions(storing=FALSE, printlevel=printlevel - 10, ...)
   #Print(same.alg, RFoptOld)
   assign("RFopt.old", RFoptOld[[1]], envir=ENVIR)
@@ -74,7 +77,7 @@ rfgui.intern <- function(data, x, y,
   
   guiReg <- GetModelRegister("gui")
   guiOpt <- RFopt$gui
-  stopifnot(guiReg == RFopt$general$guiregister)
+  stopifnot(guiReg == RFopt$registers$guiregister)
   
   OnModelSelected <- function(...)
   { 
@@ -94,45 +97,46 @@ rfgui.intern <- function(data, x, y,
       }
     }
 
-    if (exists("baseModel", where=ENVIR)) remove("baseModel", envir=ENVIR)
     modelChoiceNum <- as.numeric(tclvalue(tcl(comboBox,"current")))
-    if(modelChoiceNum == -1) 
-      return(0)
+    if(modelChoiceNum == -1) return(0)
 
     # nun zum neuen Model
     modelChoice <- models[modelChoiceNum+1]
-      selModelNum <- .C("GetModelNr", as.character(modelChoice), nr=integer(1),
+    selModelNum <- .C("GetModelNr", as.character(modelChoice), nr=integer(1),
 		      PACKAGE="RandomFields")$nr
-    assign("selModelNum",selModelNum, envir=ENVIR)
-  
-    selModelCountPar <- .C("GetNrParameters", selModelNum, k=integer(1),
-                           PACKAGE="RandomFields", DUP = FALSE)$k
 
-    ##Print(selModelCountPar, newmodel)
+    selModelCountPar <- .C("GetNrParameters", selModelNum, k=integer(1),
+                           PACKAGE="RandomFields", DUP = DUPFALSE)$k
+    dim <- as.integer(2 - sim_only1dim)  
+    newmodel <- list(modelChoice, k=rep(NA, times=selModelCountPar))
+    ##  Print(selModelCountPar, modelChoice, newmodel)
+    modelParam <- try(.Call("SetAndGetModelInfo", guiReg,
+                        list("Dummy", newmodel), dim,
+                        FALSE, FALSE, FALSE, dim,
+                        as.integer(10), ## ehemals RFoptions(short=10)
+                        TRUE, TRUE, PACKAGE="RandomFields")$minmax)
+    if (class(modelParam) == "try-error") return(0)
+
     
+    assign("selModelNum",selModelNum, envir=ENVIR)
+    if (exists("baseModel", where=ENVIR)) remove("baseModel", envir=ENVIR)
     if (selModelCountPar == 0) {
       assign("baseModel", list(modelChoice), ENVIR)
       plotDensity()
       return(0)
     }
     
-    dim <- as.integer(2 - sim_only1dim)     
-    newmodel <- list(modelChoice, k=rep(NA, times=selModelCountPar))
-    modelParam <- .Call("SetAndGetModelInfo", guiReg,
-                        list("Dummy", newmodel), dim,
-                        FALSE, FALSE, FALSE, dim,
-                        as.integer(10), ## ehemals RFoptions(short=10)
-                        TRUE, TRUE, PACKAGE="RandomFields")$minmax
    
     baseParam <- rep(NA, times=selModelCountPar)
-    if(exists(paste("remember",selModelNum,sep=""), envir=ENVIR)) 
-      baseParam <- get(paste("remember",selModelNum,sep=""), envir=ENVIR)
+    if(exists(paste("remember", selModelNum, sep=""), envir=ENVIR)) 
+      baseParam <- get(paste("remember", selModelNum, sep=""), envir=ENVIR)
 
     ## selModelCountPar > 0 hier !!
+    openeps <- 1e-10
     for (i in 1:selModelCountPar) {
       baseParam[i] <- 
         if (!is.na(baseParam[i])) baseParam[i] else
-        if (modelParam[i,3] == INTEGERLARAM) modelParam[i,2] else
+        if (modelParam[i,3] == INTEGERPARAM) modelParam[i,2] else
         if (modelParam[i,1] >=0) 0.25 * sum(sqrt(modelParam[i,1:2]))^2 + 0.1
         else 0.5 * (modelParam[i,1] + modelParam[i,2])
  
@@ -143,10 +147,11 @@ rfgui.intern <- function(data, x, y,
       # slParamName <- tklabel(tt,text=paste(toupper(substring(name, 1,1)), substring(name, 2), sep=""))
       txt <- unlist(strsplit(attr(modelParam, "dimnames")[[1]][i],"\\."))[2]
       slParamName <- tklabel(tt, text=txt)
-      slParam <- tkscale(tt, command = plotDensity, from=modelParam[i,1],
-                         to=modelParam[i,2],
+      slParam <- tkscale(tt, command = plotDensity,
+                         from= modelParam[i,1], 
+                         to = modelParam[i,2],
                          showvalue=FALSE, variable=slParamValue,
-                         resolution=if (modelParam[i,3] == INTEGERLARAM) 1 else
+                         resolution=if (modelParam[i, 3] == INTEGERPARAM) 1 else
                                 (modelParam[i,2]-modelParam[i,1])/numberSteps, 
                          orient="horizontal", length=length.slider, width=18)
       entryParam <- tkentry(tt,width=size.entry,textvariable=entryParamValue)
@@ -171,21 +176,27 @@ rfgui.intern <- function(data, x, y,
 
   OnPlotVarCovChanged <- function(...)
   {
-    if((as.character(tclvalue(plotVarCov)) == "Variogram") && !is.null(ev))
-      tkconfigure(cbPlotEV, disabled=FALSE)
-    else
-      tclvalue(plotEV) = "0" 
+    if((as.character(tclvalue(plotVarCov)) == "Variogram") && !is.null(ev)) {
+      #Print("here", cbPlotEV);
+      
+      ## tkconfigure(cbPlotEV, disabled=FALSE)
+      #Print("here end")
+    } else {
+    #
+      #Print("XXX here end")
+      tclvalue(plotEV) <- "0"
+    }
   #    tkconfigure(cbPlotEV, disabled=TRUE)
+    
+    #Print("OK")
     tkrreplot(imgVar)
   }
 
   OnplotEVChanged <- function(...)
   {
     if((as.character(tclvalue(plotVarCov)) == "Covariance") || is.null(ev))
-      tclvalue(plotEV) = "0"
-    else {
-       tkrreplot(imgVar)
-    }
+      tclvalue(plotEV) <- "0"
+    tkrreplot(imgVar)
   }
 
   OnScaleEntryChanged <- function(...)
@@ -299,6 +310,8 @@ rfgui.intern <- function(data, x, y,
   plotFunction <- function(...)
   {
 
+    #Print(tclvalue(plotEV), cbPlotEV)
+
     plotev = as.numeric(tclvalue(plotEV))
     par(cex=0.6, bg="lightgrey", mar=c(3,3,1,1))
     if(!exists("baseModel",envir=ENVIR)) {
@@ -333,9 +346,12 @@ rfgui.intern <- function(data, x, y,
     newmodel <- GetGuiModel()
     assign("RFgui.model", newmodel, envir=parent.ev)
     
-    if(as.numeric(tclvalue(showAniso))) {
+     if(as.numeric(tclvalue(showAniso))) {
       x1 <- rep(xcov, each=length(ycov))
       x2 <- rep(ycov, times=length(xcov))
+
+     # Print(newmodel, "hier")
+      
       cv <- RFvariogram(x=as.matrix(expand.grid(xcov, ycov)),
                         model=newmodel, 
                         practicalrange = tclvalue(cbPracRangeVal) != "0")
@@ -362,25 +378,33 @@ rfgui.intern <- function(data, x, y,
     }
     
     cv <- xcov
+   # Print(newmodel, xcov, as.character(tclvalue(plotVarCov)))
     if(as.character(tclvalue(plotVarCov)) == "Covariance") {
+     
       cv <- RFcov(x=xcov, model=newmodel,
                   practicalrange = tclvalue(cbPracRangeVal) != "0")
     }
-    if(as.character(tclvalue(plotVarCov)) == "Variogram") {
+    if(as.character(tclvalue(plotVarCov)) == "Variogram") {      
       pr.dummy <- tclvalue(cbPracRangeVal) != "0"
-      ##    save(file="~/xxxx", xcov, newmodel, pr.dummy)
-      ##    Print(x=xcov, model=newmodel, practicalrange = pr.dummy )
+ 
+    #  Print(newmodel, "xxx")
+      
       cv <- RFvariogram(x=xcov, model=newmodel,
                         practicalrange = pr.dummy)
+      # Print(RFgetModelInfo(RFvariogram, level=19))
     }
 
-    xm <- c(min(xcov),max(xcov))
-    ym <- c(min(cv), max(cv)*1.1)
     if(!is.null(ev) && plotev) {
-      notNA <- !is.nan(ev@emp.vario)
-      xm <- c(min(ev@centers[notNA]), max(ev@centers[notNA]))
-      ym <- c(min(ev@emp.vario[notNA]), max(ev@emp.vario[notNA])*1.1)
+      xm <- range(ev@centers, na.rm=TRUE)
+      ym <- range(ev@emp.vario, na.rm=TRUE) * c(1, 1.1)
+    } else {
+      xm <- range(xcov, na.rm=TRUE)
+      ym <- range(cv, na.rm=TRUE) * c(1, 1.1)
     }
+
+#    Print(xm, xcov, min(xcov),max(xcov), ev@centers, ym,  c(min(xcov),max(xcov)), c(min(cv), max(cv)*1.1))
+
+    
     lab <- xylabs("", NULL)
     plot(xcov[2:length(xcov)], cv[2:length(xcov)], type="l",
          xlab=lab$x, ylab="", xlim=xm, ylim=ym)
@@ -391,9 +415,9 @@ rfgui.intern <- function(data, x, y,
       points(ev@centers[!is.nan(ev@emp.vario)],
              ev@emp.vario[!is.nan(ev@emp.vario)], pch=19)
 
-    # Print(newmodel, "hierx")
+    #    Print(newmodel, "hierx")
      assign("model", newmodel, envir = ENVIR)
-  }
+  } # function
 
   plotSimulation <- function(...)
   {
@@ -419,19 +443,21 @@ rfgui.intern <- function(data, x, y,
       yy <- (if (get("simDim", envir = ENVIR) =="sim1Dim") NULL else
              if (is.null(y)) x else y)
       pr <-  tclvalue(cbPracRangeVal) != "0"
-      save(file="model", x, simu.model, yy, guiReg, pr)
 
-      z <- try(RFsimulate(x=x, grid=TRUE, model=simu.model,
-                          y=if (get("simDim", envir = ENVIR) =="sim1Dim") NULL
+  #    Print("A")
+
+      z <- try(RFsimulate(simu.model,x=x, grid=TRUE, 
+                          y=if (get("simDim", envir = ENVIR)=="sim1Dim") NULL
                           else if (is.null(y)) x else y,
                           seed = fixed.rs,
                           register=guiReg, spConform=TRUE,
                           practicalrange = tclvalue(cbPracRangeVal) != "0"),
                silent=!TRUE)
 
-      if (class(z) == "RFspatialGridDataFrame") plot(z, cex=.5)
-      else {
-        plot(Inf, Inf, xlim=c(0,1), ylim=c(0,1), axes=!FALSE, xlab="", ylab="",
+ 
+      if (class(z) == "try-error") {
+          plot(Inf, Inf, xlim=c(0,1), ylim=c(0,1), axes=!FALSE, xlab="",
+               ylab="",
              cex.main=2, col.main="brown",
               main=paste("\n\n\n\n\n\n\n\n",
                if (guiOpt$simu_method == "any method")
@@ -439,19 +465,20 @@ rfgui.intern <- function(data, x, y,
                else paste("Simulation method '", guiOpt$simu_method,
                           "'\ndoes not work for this specification", sep=""),
                ".\n\nSet 'simu_method = \"any method\"'",
-               "\nor set 'same.algorithm=TRUE'",
+               "\nor set 'same.algorithm=FALSE'",
               "\nor see RFoptions() for controlling parameters",
                if (guiOpt$simu_method != "any method")
-               paste("\nof '", guiOpt$simu_method, "'"),
+               paste("\nof '", guiOpt$simu_method, "'", sep=""),
                sep=""))
-        return(0)
+      } else {
+        plot(z, cex=.5, legend=FALSE)
       }
     }
   }
 
   
-  plotDensity <- function(...)
-  {
+  plotDensity <- function(...) {    
+#    Print("Y")
     #tkconfigure(labelOccupancy,textvariable=tclVar("Busy"))
     tkrreplot(imgVar)
     if(as.numeric(tclvalue(simAlways)))
@@ -494,17 +521,18 @@ rfgui.intern <- function(data, x, y,
 
   OnSimDimChanged <- function(...)
   {
+  
+    if(!sim_only1dim) {
+      assign("simDim", tclvalue(rb2DimValue), envir = ENVIR) 
+      tkrreplot(imgSim)
+      return (0)
+    }
+
     if(as.numeric(tclvalue(showAniso))) 
     {
       tclvalue(rb2DimValue) <-"sim2Dim"
       return(0)
     } 
-
-    if(!sim_only1dim) 
-    {
-      assign("simDim", tclvalue(rb2DimValue), envir = ENVIR) 
-      tkrreplot(imgSim)
-    }
   }
 
   OnReturn <- function(...)
@@ -663,9 +691,6 @@ rfgui.intern <- function(data, x, y,
     } else {      
       stopifnot(is(data, "RFsp"))
       if (!is.null(y)) stop("'x' and 'y' may not be given if 'data' is given.")
-
-      str(data)
-      
       r <- apply(data@coords, 2, range)
       len <- guiOpt$size[if (length(r) == 2) 1 else 2] 
       x <- seq(r[1], r[2], len=len)
@@ -710,17 +735,21 @@ rfgui.intern <- function(data, x, y,
   ##  if (exists("model", where=ENVIR)) remove("model", envir=ENVIR)
 
              
-  if(is.null(fixed.rs))
-    fixed.rs <- ifelse(exists(".Random.seed"), .Random.seed, runif(1,0,100000)) 
-
+  if(is.null(fixed.rs)) {
+    if (!exists(".Random.seed")) runif(1)
+    fixed.rs <- .Random.seed 
+  }
 
   # get all model names
   models <-
-    RFgetModelNames(type=ZF_TYPE[c(TcfType, PosDefType, UndefinedType) + 1],
-                    domain=ZF_DOMAIN[TRANS_INV + 1],
-                    isotropy=ZF_ISOTROPY[ISOTROPIC + 1],
-                    operator=FALSE, 
-                    vdim=1)#, multivariate = 1)  
+    RFgetModelNames(type=RC_TYPE[c(TcfType, PosDefType, UndefinedType) + 1],
+                    domain=RC_DOMAIN[TRANS_INV + 1],
+                    isotropy=RC_ISOTROPY[RC_ISOTROPIC + 1],
+                    operator=FALSE,
+                    valid.in.dim = if (sim_only1dim) 1 else 2,
+                    simpleArguments = TRUE,
+                    vdim=1)#, multivariate = 1)
+  models <- models[models != "RMnugget"]
   
   #-------------------------------------------------------------------
   # Start Values and ranges
@@ -728,6 +757,8 @@ rfgui.intern <- function(data, x, y,
   cbPracRangeVal <- tclVar(RFopt$general$practicalrange)
   simAlways <- tclVar(as.integer(guiOpt$alwaysSimulate))
   plotVarCov <- tclVar("Variogram")
+
+  ##Print("TTT")
   plotEV <- tclVar(ifelse(is.null(ev) && tclvalue(plotVarCov)=="Variogram",
                           "0", "1"))
   showAniso <- tclVar("0")
@@ -815,8 +846,6 @@ rfgui.intern <- function(data, x, y,
   #--- DropDown-ComboBox for model selection -------------------------
   labModelSelect <- tklabel(tt,text="Adjust Model:")
   textModell <- tclVar("Please select a model...")
-  #if(!is.null(model))
-  #  textModel <- 
   comboBox <- ttkcombobox(tt,textvariable=textModell, state="readonly",
                           values=models)
   tkbind(comboBox, "<<ComboboxSelected>>", OnModelSelected)
@@ -843,18 +872,21 @@ rfgui.intern <- function(data, x, y,
   labelVariogram <- tklabel(tt,text="Variogram")
 
   #--- Checkbox plot empirical variogram    --------------------------
+  ## checkbuttion setzt die variable und fuehrt dann noch zusaetzlich
+  ## command aus.
   cbPlotEV <- tkcheckbutton(tt, variable=plotEV, command=OnplotEVChanged)
   labelPlotEV <- tklabel(tt,text="Plot empirical variogram")
 
   #--- Radiobutton: select dimension for simulation ------------------
   rbSim1Dim <- tkradiobutton(tt, command=OnSimDimChanged)
   rbSim2Dim <- tkradiobutton(tt, command=OnSimDimChanged)
-  rb2DimValue <- tclVar(ifelse((sim_only1dim), "sim1Dim", "sim2Dim"))
+  rb2DimValue <- tclVar(if (sim_only1dim) "sim1Dim" else "sim2Dim")
   tkconfigure(rbSim1Dim,variable=rb2DimValue, value="sim1Dim")
   tkconfigure(rbSim2Dim,variable=rb2DimValue, value="sim2Dim")
   labelSim1Dim <- tklabel(tt,text="1 dim")
-  labelSim2Dim <- tklabel(tt,text="2 dim")
-  assign("simDim", as.character(tclvalue(plotVarCov)), envir=ENVIR)
+  labelSim2Dim <- tklabel(tt,text=if (sim_only1dim) "1 dim" else "2 dim")
+  assign("simDim", as.character(tclvalue(rb2DimValue)), envir=ENVIR)
+#  Print(get("simDim", envir=ENVIR)); 
 
   #--- Button - new simulation (new seed) ----------------------------
   buttonNewSimu <- tkbutton(tt,text="New Simulation",command=OnNewSimu)
@@ -867,7 +899,7 @@ rfgui.intern <- function(data, x, y,
   labelSimAlways <- tklabel(tt,text="Simulate always")
 
   #--- Checkbox Practical Range --------------------------------------
-  cbPracRange <- tkcheckbutton(tt, command=plotDensity)
+  cbPracRange <- tkcheckbutton(tt, variable=cbPracRangeVal, command=plotDensity)
   tkconfigure(cbPracRange,variable=cbPracRangeVal)
   labelPracRange <- tklabel(tt,text="Practical Range")
 
