@@ -8,7 +8,7 @@ summary.RFopt <- function(object, ...) {
 
 
 print.summary.RFopt <- function(x, ...) {
-  str(x, ...) #
+  str(x, give.attr=FALSE, ...) #
   invisible(x)
 }
 
@@ -24,7 +24,7 @@ summary.RFoptElmnt <- function(object, ...) {
 }
 
 print.summary.RFoptElmnt <- function(x, ...) {
-  str(x, ...) #
+  str(x, give.attr=FALSE, ...) #
   invisible(x)
 }
 
@@ -87,6 +87,52 @@ internal.rfoptions <- function(..., REGISTER=FALSE, COVREGISTER=as.integer(NA),
   return(RFopt)
 }
 
+
+print_RFgetModelInfo <- function(x, max.level=10-attr(x, "level"),
+                                 give.attr=FALSE, ...) {
+  str(object = x,  max.level=max.level, give.attr=give.attr, ...) #
+}
+
+print.RFgetModelInfo <- function(x, ...) {
+  print_RFgetModelInfo(x, ...) 
+}
+
+
+RFgetModelInfo <-
+  function(register, level=3, 
+           spConform=RFoptions()$general$spConform,
+           which.submodels = c("user", "internal", "both"),
+           modelname=NULL) {  
+  register <- resolve.register(if (missing(register)) NULL else
+                               if (is.numeric(register)) register else
+                               deparse(substitute(register)))
+  which.submodels <- match.arg(which.submodels)
+  ## positive values refer the covariance models in the registers
+  ##define MODEL_USER : 0  /* for user call of Covariance etc. */
+  ##define MODEL_SIMU : 1  /* for GaussRF etc */ 
+  ##define MODEL_INTERN  : 2 /* for kriging, etc; internal call of covariance */
+  ##define MODEL_MLE  : 3
+  ##define MODEL_BOUNDS  4 : - /* MLE, lower, upper */
+  ## level + 10: auch die call fctn !
+  ## [ in RF.h we have the modulus minus 1 ]
+  
+  cov <- .Call("GetExtModelInfo", as.integer(register), as.integer(level),
+               as.integer(spConform),
+               as.integer(if (which.submodels=="user") 0 else
+                          1 + (which.submodels=="both")),
+               PACKAGE="RandomFields")
+
+  if (!is.null(modelname)) {
+    cov <- search.model.name(cov, modelname, 0)
+  }
+  class(cov) <- "RFgetModelInfo"
+  attr(cov, "level") <- level
+ 
+  return(cov)
+}
+
+
+
 RFgetModelNames <- function(type = RC_TYPE, domain = RC_DOMAIN,
                             isotropy = RC_ISOTROPY, operator = c(TRUE, FALSE),
                             monotone = RC_MONOTONE,
@@ -95,6 +141,7 @@ RFgetModelNames <- function(type = RC_TYPE, domain = RC_DOMAIN,
                             valid.in.dim = c(1, Inf), 
                             vdim = c(1, 5),
                             group.by=NULL,
+                            simpleArguments = FALSE,
                             internal,
                             newnames
                             ){ #, .internal=FALSE) {
@@ -170,13 +217,13 @@ RFgetModelNames <- function(type = RC_TYPE, domain = RC_DOMAIN,
   for (i in 1:len){
     fun <- get(ls.RFmg[i], envir=envir)
     idx[i] <- is.function(fun) && is(fun, class2="RMmodelgenerator")
-    if (!idx[i]) next
-    
+    if (!idx[i]) next   
     idx[i] <- (!all(is.na(pmatch(type, fun["type"]))) &&
                !all(is.na(pmatch(domain, fun["domain"]))) &&
                !all(is.na(pmatch(isotropy, fun["isotropy"]))) &&
                fun["operator"] %in% operator &&
                !all(is.na(pmatch(monotone, fun["monotone"]))) &&
+               (!simpleArguments || fun["simpleArguments"]) &&
                fun["finiterange"] %in% finiterange &&
                (fun["maxdim"] < 0 ||
                 (fun["maxdim"] >= valid.in.dim[1] &&
