@@ -143,8 +143,8 @@ globalparam GLOBAL = {
   {true, CircEmbed, {1024, 64}},  // gui
   {true, 6, 1, {3, 4}}, // graphics
   {0, MODEL_KRIGE, MODEL_COND, MODEL_ERR, MODEL_GUI}, // registers
-  {true, true, true, true, true, 
-   true, true, false, true, true, true}, // warnings
+  {true, true, true, false, true, 
+   true, true, false, true, true, true, true, true}, // warnings
   {NA_REAL, coord_auto, {""}, {""}, {""}}, // coords
   {10}, // special
 };
@@ -262,7 +262,7 @@ void errorMSG(int err, char* m, int len) {
   case ERRORNOTDEFINED :       
     strcpy(m,"specified method undefined for the given model or no simulation method found for the given model");break;
   case ERRORNOTPROGRAMMEDYET :    
-    strcpy(m,"Not programmed yet. Sorry."); break;
+    strcpy(m,"Not programmed yet in RandomFields Version 3. Sorry."); break;
   case ERRORVDIMNOTPROGRAMMEDYET :    
     strcpy(m,"multivariate version not programmed yet. Sorry."); break;
   case ERRORTYPECONSISTENCY :
@@ -340,7 +340,13 @@ void errorMSG(int err, char* m, int len) {
   case ERRORWRONG:
     sprintf(m, "%s", ERRORSTRING_WRONG);
     break;
-    
+  case ERRORWRONGVDIM: 
+    strcpy(m, ERRORSTRING);
+    break;
+  case ERRORBADVDIM: 
+    strcpy(m, "m-dimensionality could not be detected");
+    break;
+
     // extremes:
   case ERRORSUBMETHODFAILED:
     sprintf(m, "no good submethods exist");
@@ -820,10 +826,10 @@ void InitModelList() {
   pref_type
     pbernoulli = {5, 0, 0,  0, 0, 5, 5, 0, 0, 0, 0, 0, 0, 5};
   //             CE CO CI TBM Sp di sq Ma av n mpp Hy spf any
-  IncludeModel("bernoulli", TcfType, 1, 1, 1, NULL, PREVMODELD, PREVMODELI,
+  IncludeModel("bernoulli", TcfType, 1, 1, 3, NULL, PREVMODELD, PREVMODELI,
 	       checkbinary, rangebinary, pbernoulli,
 	       false, SCALAR, SUBMODEL_DEP, SUBMODEL_DEP, SUBMODEL_DEP);
-  kappanames("threshold", REALSXP);
+  kappanames("threshold", REALSXP, "correlation", INTSXP, "centred", INTSXP);
   addCov(binary, NULL, NULL);
   
 
@@ -918,8 +924,8 @@ void InitModelList() {
   addReturns(NULL, NULL, covmatrix_constant, iscovmatrix_constant, 
 	     NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
 
-  pref_type pcox={2, 0, 0,  5, 0, 5, 5, 0, 0, 0, 0, 0, 0, 5};
-  //           CE CO CI TBM Sp di sq Ma av n mpp Hy spf any
+  pref_type pcox={2, 0, 0,  0, 0, 5, 5, 0, 0, 0, 0, 0, 0, 5};
+  //              CE CO CI TBM Sp di sq Ma av n mpp Hy spf any
   IncludeModel("coxisham",  PosDefType, 1, 1, 3, kappa_cox, 
 	       XONLY, ZEROSPACEISO, 
 	       checkcox, rangecox, pcox,
@@ -1323,8 +1329,8 @@ void InitModelList() {
 	       checkSchur, rangeSchur, PREF_ALL,
 	       false, SUBMODEL_DEP, SUBMODEL_DEP, SUBMODEL_DEP, NOT_MONOTONE);
   kappanames("M", REALSXP, "diag", REALSXP, "rhored", REALSXP);
-  addCov(Mstat, NULL, NULL);
-  addCov(Mnonstat);
+  addCov(Schurstat, NULL, NULL);
+  addCov(Schurnonstat);
   add_paramtype(paramtype_M); 
  
 
@@ -1693,7 +1699,7 @@ void InitModelList() {
 		 check_gauss_distr, range_gauss_distr, PREF_AUX, 
 		 false, PARAM_DEP, INFDIM-1, false, MISMATCH);
   nickname("gauss");
-  kappanames("mu", REALSXP, "sd", REALSXP, "log", REALSXP);
+  kappanames("mu", REALSXP, "sd", REALSXP, "log", INTSXP);
   RandomShape(INFTY, structOK, init_gauss_distr, do_gauss_distr);
   addCov(gaussD, gaussDlog, gaussDinverse, 
 	 gaussP, gaussP2sided, gaussQ, gaussR, gaussR2sided);
@@ -2323,9 +2329,8 @@ void InitModelList() {
   // Markovgauss, Markovgneiting, Markovgengneiting, Markovhyperbolic, Markovpenta, 
   // Markovpower, Markovqexponential, Markovspherical, Markovstable, 
  
-  // addusersfunctions();
-
 
+  
     int nr;
   for (nr=0; nr<currentNrCov; nr++) { 
     cov_fct *C = CovList + nr; // nicht gatternr
@@ -2739,7 +2744,11 @@ bool TrafoOK(cov_model *cov, bool all) {// check other things, too, besides gatt
 	(cov->secondarygatternr >= FIRST_TRAFO &&
 	 cov->secondarygatternr <= LAST_TRAFO)) && 
     (!all || cov->checked);  
-  //printf("ok = %d %d\n", ok, all);
+  //
+  // printf("ok = %d %d gatterNr=%d %d %d snd=%d %d %d %d \n", ok, all, 
+  //	 cov->gatternr,  FIRST_TRAFO, LAST_TRAFO,
+  //	 cov->secondarygatternr, MISMATCH, FIRST_TRAFO, LAST_TRAFO,
+  //	 );
   if (!ok) {
     PMI(cov); //
     //PMI(cov->calling->calling->calling->calling);
