@@ -97,7 +97,8 @@ void ResetWarnings() {
   internal_param *w = &(GLOBAL.internal);
   w->warn_oldstyle = w->warn_newstyle = w->warn_Aniso = w->warn_ambiguous =
     w->warn_normal_mode = w->warn_mode = w->warn_colour = w->warn_coordinates =
-    w->warn_on_grid = true;
+    w->warn_on_grid = w->warn_new_definitions = w->warn_aspect_ratio = 
+    true;
 }
 
 #define MaxMaxInts 9
@@ -226,8 +227,12 @@ void SetDefaultModeValues(int old, int m){
   w->stored_init = false;
   if (m < normal) 
     w->warn_oldstyle = w->warn_newstyle = w->warn_Aniso = w->warn_ambiguous =
-      w->warn_on_grid = false;
-  else if (m>old) w->warn_oldstyle = w->warn_Aniso = w->warn_ambiguous = true;
+      w->warn_on_grid = w->warn_aspect_ratio = false;
+  else if (m>old) { 
+    w->warn_oldstyle = w->warn_Aniso = w->warn_new_definitions = 
+      w->warn_aspect_ratio = true;
+    if (m > normal) w->warn_ambiguous = true;
+  }
   if (m != normal && w->warn_mode) {
     PRINTF("Note that the option 'modus_operandi' is still in an experimental stage, so that the behaviour may change (slightly) in future.");
     w->warn_mode = false;
@@ -439,7 +444,8 @@ void PrintModelList(int *intern, int *operat, int* Nick)
   char firstcolumn[20], name[MAXCHAR];
   int maxchar=10; // <= MAXCHAR=14
   int type[MAXNRCOVFCTS], op[MAXNRCOVFCTS], monotone[MAXNRCOVFCTS], 
-    finite[MAXNRCOVFCTS], internal[MAXNRCOVFCTS], dom[MAXNRCOVFCTS], 
+    finite[MAXNRCOVFCTS], simpleArguments[MAXNRCOVFCTS], 
+    internal[MAXNRCOVFCTS], dom[MAXNRCOVFCTS], 
     iso[MAXNRCOVFCTS], vdim[MAXNRCOVFCTS], maxdim[MAXNRCOVFCTS],
     nick = *Nick;
   
@@ -452,7 +458,8 @@ void PrintModelList(int *intern, int *operat, int* Nick)
   else {
     cov_fct *C;
 
-    GetAttr(type, op, monotone, finite, internal, dom, iso, maxdim, vdim);
+    GetAttr(type, op, monotone, finite, simpleArguments,
+	    internal, dom, iso, maxdim, vdim);
  
     sprintf(firstcolumn,"%%%ds", -maxchar);
     PRINTF("\n\n");
@@ -559,44 +566,11 @@ void GetModelList(int* idx, int*internal) {
 
 
 
-
-/*
-void GetKeyInfo(int *keyNr, int *total, int *lengths, int *spatialdim, 
-		int *timespacedim, 
-		int *grid, int *role, int *maxdim, int *vdim)
-{
-    // check with DoSimulateRF and subsequently with extremes.cc, l.170
-    // if any changings !
-  int d;
-  cov_model *key;
-  simu_type *simu;
-  location_type *loc;
-
-  if (*maxdim<MAXSIMUDIM) { *total=-3; *maxdim=MAXSIMUDIM; return;} 
-  if ((*keyNr<0) || (*keyNr>MODEL_MAX)) {*total=-1; return;} 
-  if ((key = KEY[*keyNr]) == NULL) {*total=-3; return;}  
-  simu = &(key->simu);
-  loc = key->prevloc;
-
-  if (!simu->active) {*total=-2;} 
-  else { 
-    *total=loc->totalpoints;
-    *spatialdim = loc->spatialdim;
-    *timespacedim = loc->timespacedim;
-    for (d=0; d<loc->timespacedim; d++) lengths[d]=loc->length[d];
-    *grid = (int) loc->grid;
-    *role = (int) key->role; 
-    *maxdim = MAXSIMUDIM;
-    *vdim = key->vdim;
-  }
-}
-*/
-
-
 void GetAttr(int *type, int *op, int *monotone, int *finiterange, 
+	     int *simpleArguments,
 	     int *internal, int *dom, int *iso, int *maxdim, int *vdim) {
 #define MAXPN 10 /* only used for testing purposes */
-  int nr, p;
+  int nr, p, k;
   cov_model Cov,
     *cov = &Cov;
   range_type range;
@@ -616,6 +590,12 @@ void GetAttr(int *type, int *op, int *monotone, int *finiterange,
     C->range(cov, &range);
     maxdim[nr] = C->maxdim;
     finiterange[nr] = C->finiterange;
+    simpleArguments[nr] = true;
+    for (k=0; k<C->kappas; k++) 
+      if (C->kappatype[k] != INTSXP && C->kappatype[k] != REALSXP) {
+	simpleArguments[nr] = false;
+	break;
+      }
     monotone[nr] = C->Monotone;
     internal[nr] = C->internal;
     dom[nr] = C->domain;
@@ -636,6 +616,7 @@ double Real(SEXP p, char *name, int idx) {
 	? NA_REAL : (double) INTEGER(p)[idx];
     case LGLSXP : return LOGICAL(p)[idx]==NA_LOGICAL ? NA_REAL 
 	: (double) LOGICAL(p)[idx];
+    default : {}
     }
   // MEMCOPY(msg, p, 300); print("%s\n", msg);
   sprintf(msg, "'%s' cannot be transformed to double! (type=%d)\n",
@@ -683,6 +664,7 @@ int Integer(SEXP p, char *name, int idx, bool nulltoNA) {
       }
     case LGLSXP :
       return  LOGICAL(p)[idx]==NA_LOGICAL ? NA_INTEGER : (int) LOGICAL(p)[idx];
+    default : {}
     }
   } else if (nulltoNA) return NA_INTEGER;
   sprintf(msg, "%s: unmatched type of parameter [type=%d]", name, TYPEOF(p));
@@ -719,6 +701,7 @@ bool Logical(SEXP p, char *name, int idx) {
     case INTSXP :
       return INTEGER(p)[idx]==NA_INTEGER ? NA_LOGICAL : (bool) INTEGER(p)[idx];
     case LGLSXP : return LOGICAL(p)[idx];
+    default : {}
     }
   sprintf(msg, "'%s' cannot be transformed to logical.\n", name);  
   ERR(msg);
@@ -827,10 +810,10 @@ void getUnits(SEXP el, char VARIABLE_IS_NOT_USED *name,
     l = length(el);
   if (TYPEOF(el) != NILSXP && TYPEOF(el) == STRSXP && l >= 1) {
     for (i=j=0; i<MAXUNITS; i++, j=(j + 1) % l) {
-      strncpy(units[i], CHAR(STRING_ELT(el, j)), MAXUNITSCHAR);
+      strcopyN(units[i], CHAR(STRING_ELT(el, j)), MAXUNITSCHAR);
       units[i][MAXUNITSCHAR - 1] ='\0';		    
       if (units2!=NULL) {
-	strncpy(units2[i], CHAR(STRING_ELT(el, j)), MAXUNITSCHAR);
+	strcopyN(units2[i], CHAR(STRING_ELT(el, j)), MAXUNITSCHAR);
         units2[i][MAXUNITSCHAR - 1] ='\0';		    
       }
     }
@@ -1056,13 +1039,14 @@ const char *registers[registersN] =
    "errregister", "guiregister"};
 
 
-#define internalN 11
+#define internalN 13
 const char * internals[internalN] =  { // Achtung ! warn parameter werden nicht
   // pauschal zurueckgesetzt
   "warn_oldstyle", "warn_newstyle", "warn_newAniso", 
   "warn_ambiguous", "warn_normal_mode",  "warn_mode",
   "warn_colour_palette", "stored.init",  "warn_scale", 
-  "on_grid", "warn_coordinates"
+  "warn_on_grid", "warn_coordinates", "warn_new_definitions",
+  "warn_aspect_ratio"
 };
 
 
@@ -1186,6 +1170,8 @@ void setparameter(SEXP el, char *prefix, char *mainname, bool isList) {
       gp->Rprintlevel = INT;
       PL = gp->Cprintlevel = 
 	gp->Rprintlevel <= threshold ? gp->Rprintlevel : threshold;
+
+
     }
       break;
     case 2: {
@@ -1695,6 +1681,8 @@ void setparameter(SEXP el, char *prefix, char *mainname, bool isList) {
       case 8: wp->warn_scale = LOG;       break;
       case 9: wp->warn_coordinates = LOG;       break;
       case 10: wp->warn_on_grid = LOG;       break;
+      case 11: wp->warn_new_definitions = LOG;       break;
+      case 12: wp->warn_aspect_ratio = LOG;       break;
       default: ERR("unknown option for 'warn'");
       }
     } else {
@@ -2103,6 +2091,8 @@ SEXP getRFoptions() {
     ADD(ScalarLogical(p->warn_scale));
     ADD(ScalarLogical(p->warn_coordinates));
     ADD(ScalarLogical(p->warn_on_grid));
+    ADD(ScalarLogical(p->warn_new_definitions));
+    ADD(ScalarLogical(p->warn_aspect_ratio));
   }
 
 
@@ -2165,9 +2155,9 @@ void splitAndSet(SEXP el, char *name, bool isList) {
   if (i==0) ERR(msg);
   if (i==len) {
     strcpy(prefix, "");
-    strncpy(mainname, name, 200);
+    strcopyN(mainname, name, 200);
   } else {
-    strncpy(prefix, name, i);
+    strcopyN(prefix, name, i);
     prefix[i] = '\0';
     strcpy(mainname, name+i+1);
   }
